@@ -10,7 +10,10 @@ export NM=nm.exe
 export CC=gcc
 export ac_cv_func_mmap_dev_zero=no
 export lt_cv_sys_max_cmd_len=12000
+export ac_cv_prog_LN='ln -s'
+export ac_cv_prog_LN_S='ln -s'
 export ac_cv_prog_AWK='awk'
+export LC_NUMERIC=.
 CONFIG_SHELL=`/bin/sh -c 'echo $0'`
 case $CONFIG_SHELL in *.exe) ;; *) CONFIG_SHELL=$CONFIG_SHELL.exe ;; esac
 export CONFIG_SHELL
