@@ -1,7 +1,7 @@
 #! /bin/sh
 
 top=`pwd`
-gcc_version=7.5.0
+gcc_version=9.3.0
 contact="Andris Pavenis <andris.pavenis@iki.fi>";
 
 # Configuration params
@@ -73,18 +73,7 @@ short_ver=$(echo $version | sed -e 's:\.::2g')
 #  X.Y.Z ==> XYZ
 short_ver_2=$(echo $version | sed -e 's:\.::g')
 
-if test -z "$devphase"; then
-    case "$base_ver" in
-        [5-9].[1-9].0)
-            ;;
-        *)
-            version=${base_ver}-${datestamp}
-            version_desc="$base_ver $datestamp"
-            short_ver=${short_ver}-$datestamp
-            short_ver_2=${short_ver_2}-$datestamp
-            ;;
-    esac
-else
+if ! test -z "$devphase"; then
     version=${base_ver}-${datestamp}
     version_desc="$base_ver $datestamp ($devphase)"
     short_ver=${short_ver}-$datestamp
@@ -112,23 +101,18 @@ rm -rf manifest
 #  Remove parts we don't need for DJGPP
 #
 
-rm -rf $gcc_dir/boehm-gc
-rm -rf $gcc_dir/fastjar
-rm -rf $gcc_dir/libffi
-rm -rf $gcc_dir/libjava
-rm -rf $gcc_dir/libchill
 rm -rf $gcc_dir/libsanitizer
 rm -rf $gcc_dir/zlib
 rm -rf $gcc_dir/libgomp
 rm -rf $gcc_dir/libgo
 rm -rf $gcc_dir/gotools
 rm -rf $gcc_dir/gcc/go
-rm -rf $gcc_dir/gcc/java
-rm -rf $gcc_dir/gcc/treelang
-rm -rf $gcc_dir/libmudflap
 rm -rf $gcc_dir/libcilkrts
 rm -rf $gcc_dir/liboffloadmic
 rm -rf $gcc_dir/libvtv
+rm -rf $gcc_dir/libatomic
+rm -rf $gcc_dir/libitm
+rm -rf $gcc_dir/libmpx
 
 if $remove_tests ; then
     for name in $(cd $gcc_dir/gcc/testsuite && ls -1b | grep -v selftest); do
